Coverage for api/assets.py: 38%

# Coverage for api/assets.py : 38%

## 6 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from flask import current_app

2 from flask import url_for

3

4

5 def get_static(boxormodule, filename):

6 if current_app.config["DEBUG"] is True:

7 return url_for("devstatic", boxormodule=boxormodule, filename=filename)

8 else:

9 return url_for("static", filename=f"modules/{boxormodule}/{filename}")